[![badge doc](https://img.shields.io/badge/docs-v6.1.0-orange.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.measure/v6.1.0/sphinx/index.html)
[![badge pipeline](https://gitlab.idiap.ch/bob/bob.measure/badges/v6.1.0/pipeline.svg)](https://gitlab.idiap.ch/bob/bob.measure/commits/v6.1.0)
[![badge coverage](https://gitlab.idiap.ch/bob/bob.measure/badges/v6.1.0/coverage.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.measure/v6.1.0/coverage/)
[![badge gitlab](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/bob/bob.measure)

# Experiment Evaluation Metrics for Bob

This package is part of the signal-processing and machine learning toolbox
[Bob](https://www.idiap.ch/software/bob). It contains common routines for
assessing performance of machine learning experiments.

## Installation

Complete Bob's
[installation instructions](https://www.idiap.ch/software/bob/install).

Then, to install this package, run:

``` sh
conda install bob.measure
```

## Contact

For questions or reporting issues to this software package, contact our
development [mailing list](https://www.idiap.ch/software/bob/discuss).
